@@ -28,7 +28,7 @@ require CGI::Portable::AdapterCGI;
 my $io = CGI::Portable::AdapterCGI->new();
 
 $io->fetch_user_input( $globals );
-$globals->call_component( 'X10' );
+$globals->call_component( 'DemoX10' );
 $io->send_user_output( $globals );
 
 1;
