@@ -86,7 +86,7 @@ use IO::Socket;
 		my $content = $globals->make_new_context();
 
 		$io->fetch_user_input( $content, $client );
-		$content->call_component( 'Aardvark' );
+		$content->call_component( 'DemoAardvark' );
 		$io->send_user_output( $content, $client );
 
 		close $client;
